User Details
- User Since
- Sep 28 2014, 7:22 PM (631 w, 4 d)
Mon, Nov 2
Fri, Oct 30
Should we try to account for a VLAN header here too?
Other than Mark's remark I think this looks good.
Other than not removing the pfvar.h include I'm happy with the pf changes, but please try to get someone to okay the addition in sys/time.h too.
Thu, Oct 29
Wed, Oct 21
Tue, Oct 20
Do we have measurements of what difference this makes?
Mon, Oct 19
The commit message needs to answer the 'why' question.
Why do we want this? We already have if_bridge, what does veb do that if_bridge does not?
Fri, Oct 16
Thu, Oct 15
Tue, Oct 13
Good, ship it ;)
That looks correct, but I don't quite follow the commit message. As far as I can tell nothing in userspace ever sends PF_ST_ID.
I suspect I left those out because nothing uses them, but we may as well add them to libpfctl anyway.
Given that we (Netgate certainly, and FreeBSD mostly too) no longer care about armv7 I wonder if we shouldn't back out the armv7 specific code from pf entirely at this point.
Mon, Oct 12
Sun, Oct 11
Oct 6 2026
Oct 3 2026
That test seems to fail for me with failed: 0 != 2 (0 != 2). The ping doesn't find a route:
Oct 2 2026
I wonder if we shouldn't just remove these versions of the get_states functions altogether.
Approved.
Oct 1 2026
Sep 30 2026
Sep 29 2026
Approved.
That looks sane, but I'd really like to have a test case for this as well.
Sep 25 2026
Sep 21 2026
Sep 18 2026
Sep 15 2026
Sep 7 2026
Sep 3 2026
Sorry, I don't take LLM generated code. I am unwilling to bear the copyright risk, unwilling to expend the addition effort required to review them and just generally unwilling to support that industry.
It's not applicable to the tests, but for pf itself it would also prevent me from sharing code with OpenBSD because they also do not take LLM generated patches.
Sep 1 2026
I've never used that, no. I don't really have a need for that, although I suppose the automatic re-running of failed tests is interesting.
Aug 31 2026
That's an interesting idea.
Running the pf tests (at parallelism=4) that knocks the runtime down from 16 minutes to 10 minutes, which is pretty impressive.
Aug 27 2026
Aug 26 2026
I think the patch is fine now, but I would like to see the flame graphs anyway, so we're sure this does what we think it does.
